module Test
  {-# DEPRECATED "This module is unstable" #-}
  (foo, bar, baz)
where

import Blah
